@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     jingzhou <jingzhou@uniontech.com>
-*
-* Maintainer: xiajing <xiajing@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "memorywidget.h"
 
@@ -357,7 +341,7 @@ QString MemoryWidget::programmerWrap(QString result)
         block = 4;
 
     while (r < result.length()) {
-        if (fm.width(result.mid(l, r - l)) < validwidth)
+        if (fm.horizontalAdvance(result.mid(l, r - l)) < validwidth)
             ++r;
         else {
             while (result.at(r) != QLatin1String(" ") && result.at(r) != QLatin1String(",")) {
