@@ -1,21 +1,7 @@
-/*
-* Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     jingzhou <jingzhou@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "proexpressionbar.h"
 
@@ -919,7 +905,11 @@ void ProExpressionBar::initTheme(int type)
 void ProExpressionBar::revisionResults(const QModelIndex &index)
 {
     QString text = index.data(SimpleListModel::ExpressionRole).toString();
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     QStringList historic = text.split(QString("＝"), QString::SkipEmptyParts);
+#else
+    QStringList historic = text.split("＝", Qt::SkipEmptyParts);
+#endif
     if (historic.size() != 2)
         return;
     QString expression = historic.at(0);
@@ -961,6 +951,7 @@ void ProExpressionBar::copyClipboard2Result()
     int curpos = m_inputEdit->cursorPosition(); //未粘贴操作的光标位
     QString text = Utils::toHalfWidth(QApplication::clipboard()->text());
     text = text.left(text.indexOf("="));
+    text = text.toUpper();
     text = text.replace('+', QString::fromUtf8("＋"))
            .replace('-', QString::fromUtf8("－"))
            .replace("_", QString::fromUtf8("－"))
