@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     xiajing <xiajing@uniontech.com>
-*
-* Maintainer: jingzhou <jingzhou@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "sciexpressionbar.h"
 
@@ -30,6 +14,8 @@
 #include <QDebug>
 #include <QTimer>
 #include <DGuiApplicationHelper>
+#include <QRandomGenerator>
+#include <QtGlobal>
 
 const int SCIPREC = 31; //科学计算器精度
 const int LIST_HEIGHT = 35; //输入栏上方表达式的高度
@@ -587,8 +573,9 @@ void SciExpressionBar::enterRandEvent()
     m_isResult = false;
     m_isUndo = false;
     QString str;
+    QRandomGenerator* randGen = QRandomGenerator::system();
     for (int i = 0; i < SCIPREC; i++) {
-        int n = qrand() % 10;
+        int n = randGen->generate() % 10;
         str.append(QString::number(n));
     }
     str = "0." + str;
@@ -1111,7 +1098,11 @@ void SciExpressionBar::revisionResults(const QModelIndex &index)
 {
 //    clearLinkageCache(m_inputEdit->text(), false);
     QString text = index.data(SimpleListModel::ExpressionRole).toString();
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     QStringList historic = text.split(QString("＝"), QString::SkipEmptyParts);
+#else
+    QStringList historic = text.split("＝", Qt::SkipEmptyParts);
+#endif
     if (historic.size() != 2)
         return;
     QString expression = historic.at(0);
